| simCAT_MX | R Documentation |
A simulated dataset for computerized adaptive testing (CAT), containing an item pool, sparse response data, and examinee ability estimates. The item pool includes both dichotomous and polytomous items.
simCAT_MX
A list of length three:
A data frame in item metadata format consisting of 200 dichotomous items and 30 polytomous items.
Dichotomous items: Calibrated using the IRT 3PL model.
Polytomous items: Calibrated using the Generalized Partial Credit Model (GPCM), with three score categories (0, 1, 2).
A sparse matrix of item responses from 30,000 examinees.
A numeric vector of ability estimates for the 30,000 examinees.
Hwanggyu Lim hglim83@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.