summary: Summary of Item Calibration Results

View source: R/summary.R

summaryR Documentation

Summary of Item Calibration Results

Description

This S3 method summarizes the IRT calibration results from an object of class est_irt, est_mg, or est_item, which are returned by the functions est_irt(), est_mg(), and est_item(), respectively.

Usage

summary(object, ...)

## S3 method for class 'est_irt'
summary(object, ...)

## S3 method for class 'est_mg'
summary(object, ...)

## S3 method for class 'est_item'
summary(object, ...)

Arguments

object

An object of class est_irt, est_mg, or est_item.

...

Additional arguments passed to or from other methods (currently not used).

Value

A list of internal components extracted from the given object. In addition, the summary method prints an overview of the IRT calibration results to the console.

Methods (by class)

  • summary(est_irt): An object created by the function est_irt().

  • summary(est_mg): An object created by the function est_mg().

  • summary(est_item): An object created by the function est_item().

Author(s)

Hwanggyu Lim hglim83@gmail.com

See Also

est_irt(), est_mg(), est_item()

Examples


# Fit the 1PL model to LSAT6 data and constrain the slope parameters to be equal
fit.1pl <- est_irt(data = LSAT6, D = 1, model = "1PLM", cats = 2, fix.a.1pl = FALSE)

# Display the calibration summary
summary(fit.1pl)



irtQ documentation built on July 27, 2026, 9:08 a.m.