Skip to contents

Prepares the full, detailed report for an object of class "ctt" returned by ctt(). Following the convention used by est_irt()/summary.est_irt(), this method returns an object of class "summary.ctt" whose own print.summary.ctt() method displays the complete item-level table, test-level reliability summary, and total-score frequency distribution.

Usage

# S3 method for class 'ctt'
summary(object, ...)

Arguments

object

An object of class "ctt", as returned by ctt().

...

Additional arguments passed to or from other methods (currently not used).

Value

An object of class "summary.ctt": a list with the same item, crit, alpha, freq, and call elements as object (see ctt()'s Value), to be displayed by print.summary.ctt().

See also

Author

Hwanggyu Lim hglim83@gmail.com