| print.ctt | R Documentation |
Prints a condensed, headline-style summary of an object of class "ctt"
returned by ctt(), following the same brief/full print-summary split
used by est_irt() (compare print.est_irt() vs.
summary.est_irt()/print.summary.est_irt()).
## S3 method for class 'ctt'
print(x, digits = 3, ...)
x |
An object of class |
digits |
Number of decimal places used when rounding numeric values
for display. Default is |
... |
Additional arguments passed to or from other methods (currently not used). |
x, invisibly.
Hwanggyu Lim hglim83@gmail.com
ctt(), summary.ctt()
# simulate the responses of 300 examinees to 15 dichotomous 3PLM items
set.seed(1)
x <- shape_df(
par.drm = list(a = rep(1.5, 15), b = seq(-1.5, 1.5, length.out = 15),
g = rep(0.2, 15)),
cats = 2, model = "3PLM"
)
dat <- simdat(x = x, theta = rnorm(300), D = 1)
# run the CTT analysis
out <- ctt(data = dat)
# print the condensed report
print(out)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.