| simCAT_DC | R Documentation |
A simulated dataset containing an item pool, sparse response data, and examinee ability estimates, designed for single-item computerized adaptive testing (CAT).
simCAT_DC
A list of length three:
A data frame in item metadata format containing 100 dichotomous items.
Items 1-90: Generated and calibrated under the IRT 2PL model.
Items 91-100: Generated under the IRT 3PL model but calibrated using the 2PL model.
A sparse matrix of item responses from 10,000 examinees.
A numeric vector of ability estimates for the 10,000 examinees.
Hwanggyu Lim hglim83@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.